@@ -6,7 +6,7 @@ from .WaveAnalysisFun import *
 from .WaveletFun import *
 
 
-__all__ = [s for s in dir()]
+__all__ = [s for s in dir() if not s.startswith('_')]
 try:
     # In Python 2.x the name of the tempvar leaks out of the list
     # comprehension.  Delete it to not make it show up in the main namespace.
@@ -17,4 +17,4 @@ except NameError:
 
 
 __name__ = 'BrainAnalysisTool'
-__version__ = '0.0.2'
\ No newline at end of file
+__version__ = '0.0.3'
\ No newline at end of file
